@@ -35,12 +35,14 @@ sub get_config_file ()
     "redhat-8.0"      => "redhat-6.2",
     "mandrake-9.0"    => "redhat-6.2",
     "debian-3.0"      => "redhat-6.2",
+    "ubuntu-7.04"     => "redhat-6.2",
     "suse-9.0"        => "redhat-6.2",
     "slackware-9.1.0" => "redhat-6.2",
     "gentoo"          => "redhat-6.2",
     "pld-1.0"         => "pld-1.0",
     "vine-3.0"        => "redhat-6.2",
     "freebsd-5"       => "redhat-6.2",
+    "archlinux"       => "redhat-6.2",
     "solaris-2.11"    => "solaris-2.11",
   );
 
@@ -149,6 +151,11 @@ sub apply_ntp_date
       $servers .= " $server";
   }
 
+  if ($server eq "") {
+      # There are no servers, pick them from the ntp.org pool
+      $server = "0.pool.ntp.org 1.pool.ntp.org 2.pool.ntp.org";
+  }
+
   # run ntpdate, this will only be effective
   # when there isn't any NTP server running
   &Utils::File::run ("ntpdate -b $servers") if ($servers);
@@ -165,4 +172,12 @@ sub set
   return &set_ntp_servers (@_);
 }
 
+sub get_files
+{
+  my ($files);
+
+  push @$files, &get_config_file ();
+  return $files;
+}
+
 1;
