@@ -40,6 +40,7 @@ my $PLATFORM_INFO = {
   "ubuntu-6.10"     => [ "Ubuntu Linux", "6.10", "Edgy" ],
   "ubuntu-7.04"     => [ "Ubuntu Linux", "7.04", "Feisty" ],
   "ubuntu-7.10"     => [ "Ubuntu Linux", "7.10", "Gutsy" ],
+  "ubuntu-8.04"     => [ "Ubuntu Linux", "8.04", "Hardy" ],
   "redhat-5.2"      => [ "Red Hat Linux", "5.2", "Apollo" ],
   "redhat-6.0"      => [ "Red Hat Linux", "6.0", "Hedwig" ],
   "redhat-6.1"      => [ "Red Hat Linux", "6.1", "Cartman" ],
@@ -151,6 +152,7 @@ sub ensure_distro_map
      "ubuntu-6.06"      => "debian-3.0",
      "ubuntu-6.10"      => "debian-3.0",
      "ubuntu-7.10"      => "ubuntu-7.04",
+     "ubuntu-8.04"      => "ubuntu-7.04",
      "vine-3.1"         => "vine-3.0",
      "vlos-1.2"         => "gentoo",
      "nexenta-1.0"      => "solaris-2.11",
